@@ -23,9 +23,7 @@
 
 #define HAVE_NR_PROCESS_VM_READV 1
 
-#ifndef HAVE_LIBCOMPRESSION
-/* #undef HAVE_LIBCOMPRESSION */
-#endif
+#define HAVE_LIBCOMPRESSION 0
 
 #define LLDB_ENABLE_POSIX 1
 
@@ -41,11 +39,11 @@
 
 #define LLDB_ENABLE_LIBEDIT 1
 
-#define LLDB_ENABLE_LIBXML2 0
+#define LLDB_ENABLE_LIBXML2 1
 
 #define LLDB_ENABLE_LUA 0
 
-#define LLDB_ENABLE_PYTHON 0
+#define LLDB_ENABLE_PYTHON 1
 
 #define LLDB_ENABLE_FBSDVMCORE 0
 
@@ -57,6 +55,6 @@
 
 /* #undef LLDB_GLOBAL_INIT_DIRECTORY */
 
-#define LLDB_BUG_REPORT_URL "https://github.com/llvm/llvm-project/issues/"
+#define LLDB_BUG_REPORT_URL ""
 
 #endif // #ifndef LLDB_HOST_CONFIG_H
